@@ -8,12 +8,16 @@ pytest_plugins = 'setuptools.tests.fixtures'
 
 def pytest_addoption(parser):
     parser.addoption(
-        "--package_name", action="append", default=[],
+        "--package_name",
+        action="append",
+        default=[],
         help="list of package_name to pass to test functions",
     )
     parser.addoption(
-        "--integration", action="store_true", default=False,
-        help="run integration tests (only)"
+        "--integration",
+        action="store_true",
+        default=False,
+        help="run integration tests (only)",
     )
 
 
@@ -32,6 +36,7 @@ collect_ignore = [
     'pkg_resources/tests/data',
     'setuptools/_vendor',
     'pkg_resources/_vendor',
+    'setuptools/config/_validate_pyproject',
 ]
 
 
@@ -40,6 +45,10 @@ if sys.version_info < (3, 6):
     collect_ignore.append('pavement.py')
 
 
+if sys.version_info < (3, 9) or sys.platform == 'cygwin':
+    collect_ignore.append('tools/finalize.py')
+
+
 @pytest.fixture(autouse=True)
 def _skip_integration(request):
     running_integration_tests = request.config.getoption("--integration")
