@@ -9,7 +9,7 @@ html_theme = "furo"
 # Link dates and other references in the changelog
 extensions += ['rst.linker']
 link_files = {
-    '../CHANGES.rst': dict(
+    '../NEWS.rst': dict(
         using=dict(
             BB='https://bitbucket.org',
             GH='https://github.com',
@@ -100,16 +100,19 @@ intersphinx_mapping = {
 # Preserve authored syntax for defaults
 autodoc_preserve_defaults = True
 
-intersphinx_mapping.update({
-    'pip': ('https://pip.pypa.io/en/latest', None),
-    'build': ('https://pypa-build.readthedocs.io/en/latest', None),
-    'PyPUG': ('https://packaging.python.org/en/latest/', None),
-    'packaging': ('https://packaging.pypa.io/en/latest/', None),
-    'twine': ('https://twine.readthedocs.io/en/stable/', None),
-    'importlib-resources': (
-        'https://importlib-resources.readthedocs.io/en/latest', None
-    ),
-})
+intersphinx_mapping.update(
+    {
+        'pip': ('https://pip.pypa.io/en/latest', None),
+        'build': ('https://pypa-build.readthedocs.io/en/latest', None),
+        'PyPUG': ('https://packaging.python.org/en/latest/', None),
+        'packaging': ('https://packaging.pypa.io/en/latest/', None),
+        'twine': ('https://twine.readthedocs.io/en/stable/', None),
+        'importlib-resources': (
+            'https://importlib-resources.readthedocs.io/en/latest',
+            None,
+        ),
+    }
+)
 
 # Support tooltips on references
 extensions += ['hoverxref.extension']
@@ -219,15 +222,17 @@ extensions += ['sphinxcontrib.towncrier']
 towncrier_draft_working_directory = '..'
 # Avoid an empty section for unpublished changes.
 towncrier_draft_include_empty = False
+# sphinx-contrib/sphinxcontrib-towncrier#81
+towncrier_draft_config_path = 'towncrier.toml'
 
 extensions += ['jaraco.tidelift']
 
 # Add icons (aka "favicons") to documentation
-extensions += ['sphinx-favicon']
+extensions += ['sphinx_favicon']
 html_static_path = ['images']  # should contain the folder with icons
 
 # Add support for nice Not Found 404 pages
-extensions += ['notfound.extension']
+# extensions += ['notfound.extension']  # readthedocs/sphinx-notfound-page#219
 
 # List of dicts with <link> HTML attributes
 # static-file points to files in the html_static_path (href is computed)
@@ -236,13 +241,13 @@ favicons = [
         "rel": "icon",
         "type": "image/svg+xml",
         "static-file": "logo-symbol-only.svg",
-        "sizes": "any"
+        "sizes": "any",
     },
     {  # Version with thicker strokes for better visibility at smaller sizes
         "rel": "icon",
         "type": "image/svg+xml",
         "static-file": "favicon.svg",
-        "sizes": "16x16 24x24 32x32 48x48"
+        "sizes": "16x16 24x24 32x32 48x48",
     },
     # rel="apple-touch-icon" does not support SVG yet
 ]
