@@ -4,10 +4,13 @@ from jaraco import path
 from setuptools.glob import glob
 
 
-@pytest.mark.parametrize('tree, pattern, matches', (
-    ('', b'', []),
-    ('', '', []),
-    ('''
+@pytest.mark.parametrize(
+    'tree, pattern, matches',
+    (
+        ('', b'', []),
+        ('', '', []),
+        (
+            '''
      appveyor.yml
      CHANGES.rst
      LICENSE
@@ -16,8 +19,12 @@ from setuptools.glob import glob
      README.rst
      setup.cfg
      setup.py
-     ''', '*.rst', ('CHANGES.rst', 'README.rst')),
-    ('''
+     ''',
+            '*.rst',
+            ('CHANGES.rst', 'README.rst'),
+        ),
+        (
+            '''
      appveyor.yml
      CHANGES.rst
      LICENSE
@@ -26,8 +33,12 @@ from setuptools.glob import glob
      README.rst
      setup.cfg
      setup.py
-     ''', b'*.rst', (b'CHANGES.rst', b'README.rst')),
-))
+     ''',
+            b'*.rst',
+            (b'CHANGES.rst', b'README.rst'),
+        ),
+    ),
+)
 def test_glob(monkeypatch, tmpdir, tree, pattern, matches):
     monkeypatch.chdir(tmpdir)
     path.build({name: '' for name in tree.split()})
